__title__ = "dxh"
__version__ = "0.1.3"
__description__ = "dxh is Convert python objects to camel case and snake case keys using this library."
__author__ = "Mohammad Foysal"
__url__ = "https://github.com/iamfoysal/dxh"
__license__ = "MIT"
__keywords__ = [
    "python", "object", "convert", "camel", "snake", "case", "keys", "to", "camel", "case",
]



import re
from bs4 import BeautifulSoup

def snake_to_camel(key):
    components = key.split('_')
    return components[0] + ''.join(x.title() for x in components[1:])

def keys_to_camel_case(data):
    if isinstance(data, dict):
        new_data = {}
        for key, value in data.items():
            new_key = snake_to_camel(key)
            new_value = keys_to_camel_case(value)
            new_data[new_key] = new_value
        return new_data
    elif isinstance(data, list):
        return [keys_to_camel_case(item) for item in data]
    else:
        return data




def camel_to_snake(key):
    pattern = re.compile(r'(.)([A-Z][a-z]+)')
    return pattern.sub(r'\1_\2', key).lower()

def keys_to_snake_case(data):
    if isinstance(data, dict):
        new_data = {}
        for key, value in data.items():
            new_key = camel_to_snake(key)
            new_value = keys_to_snake_case(value)
            new_data[new_key] = new_value
        return new_data
    elif isinstance(data, list):
        return [keys_to_snake_case(item) for item in data]
    else:
        return data

def rich_to_plain(rich_text):
    sp = BeautifulSoup(rich_text, 'html.parser')
    pt = sp.get_text(separator=' ')
    pt = ' '.join(pt.split())
    pt = re.sub(r'[\n\r]+', ' ', pt)
    pt = re.sub(r'\s*•\s*', ' ', pt)
    pt = re.sub(r'\s*-\s*', ' ', pt)
    return pt




from .obj_converter import keys_to_camel_case, keys_to_snake_case
from .__version__ import (  # noqa: F401
    __title__,
    __version__,
    __description__,
    __author__,
    __url__,
    __license__,
    __keywords__,
    
)

__all__ = ["keys_to_camel_case", "keys_to_snake_case"]



import setuptools

about = dict()

with open("dxh/__version__.py", "r") as f:
    exec(f.read(), about)

with open("README.md", "r") as f:
    long_description = f.read()

# with open("requirements.txt", "r") as f:
#     install_requires = f.read().splitlines()

setuptools.setup(
    name=about["__title__"],
    version=about["__version__"],
    description=about["__description__"],
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=about["__author__"],
    url=about["__url__"],
    license=about["__license__"],
    keywords=about["__keywords__"],
    packages=setuptools.find_packages(".", exclude=["*.tests"]),
    install_requires=[
        "requests",
        "beautifulsoup4", 
    ],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.9",
    project_urls={"Source": about["__url__"]},
)
